==> stepfunctions-1.60.0-sources.jar: software/amazon/awscdk/services/stepfunctions/AfterwardsOptions.java <==
package software.amazon.awscdk.services.stepfunctions;

/**
 * Options for selecting the choice paths.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:13.471Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.AfterwardsOptions")
@software.amazon.jsii.Jsii.Proxy(AfterwardsOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AfterwardsOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether to include error handling states.
     * <p>
     * If this is true, all states which are error handlers (added through 'onError')
     * and states reachable via error handlers will be included as well.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getIncludeErrorHandlers() {
        return null;
    }

    /**
     * Whether to include the default/otherwise transition for the current Choice state.
     * <p>
     * If this is true and the current Choice does not have a default outgoing
     * transition, one will be added included when .next() is called on the chain.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getIncludeOtherwise() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AfterwardsOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AfterwardsOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AfterwardsOptions> {
        private java.lang.Boolean includeErrorHandlers;
        private java.lang.Boolean includeOtherwise;

        /**
         * Sets the value of {@link AfterwardsOptions#getIncludeErrorHandlers}
         * @param includeErrorHandlers Whether to include error handling states.
         *                             If this is true, all states which are error handlers (added through 'onError')
         *                             and states reachable via error handlers will be included as well.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder includeErrorHandlers(java.lang.Boolean includeErrorHandlers) {
            this.includeErrorHandlers = includeErrorHandlers;
            return this;
        }

        /**
         * Sets the value of {@link AfterwardsOptions#getIncludeOtherwise}
         * @param includeOtherwise Whether to include the default/otherwise transition for the current Choice state.
         *                         If this is true and the current Choice does not have a default outgoing
         *                         transition, one will be added included when .next() is called on the chain.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder includeOtherwise(java.lang.Boolean includeOtherwise) {
            this.includeOtherwise = includeOtherwise;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AfterwardsOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AfterwardsOptions build() {
            return new Jsii$Proxy(includeErrorHandlers, includeOtherwise);
        }
    }

    /**
     * An implementation for {@link AfterwardsOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AfterwardsOptions {
        private final java.lang.Boolean includeErrorHandlers;
        private final java.lang.Boolean includeOtherwise;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.includeErrorHandlers = this.jsiiGet("includeErrorHandlers", java.lang.Boolean.class);
            this.includeOtherwise = this.jsiiGet("includeOtherwise", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Boolean includeErrorHandlers, final java.lang.Boolean includeOtherwise) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.includeErrorHandlers = includeErrorHandlers;
            this.includeOtherwise = includeOtherwise;
        }

        @Override
        public java.lang.Boolean getIncludeErrorHandlers() {
            return this.includeErrorHandlers;
        }

        @Override
        public java.lang.Boolean getIncludeOtherwise() {
            return this.includeOtherwise;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIncludeErrorHandlers() != null) {
                data.set("includeErrorHandlers", om.valueToTree(this.getIncludeErrorHandlers()));
            }
            if (this.getIncludeOtherwise() != null) {
                data.set("includeOtherwise", om.valueToTree(this.getIncludeOtherwise()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-stepfunctions.AfterwardsOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AfterwardsOptions.Jsii$Proxy that = (AfterwardsOptions.Jsii$Proxy) o;

            if (this.includeErrorHandlers != null ? !this.includeErrorHandlers.equals(that.includeErrorHandlers) : that.includeErrorHandlers != null) return false;
            return this.includeOtherwise != null ? this.includeOtherwise.equals(that.includeOtherwise) : that.includeOtherwise == null;
        }

        @Override
        public int hashCode() {
            int result = this.includeErrorHandlers != null ? this.includeErrorHandlers.hashCode() : 0;
            result = 31 * result + (this.includeOtherwise != null ? this.includeOtherwise.hashCode() : 0);
            return result;
        }
    }
}

==> stepfunctions-1.101.0-sources.jar: software/amazon/awscdk/services/stepfunctions/AfterwardsOptions.java <==
package software.amazon.awscdk.services.stepfunctions;

/**
 * Options for selecting the choice paths.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:42.238Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.AfterwardsOptions")
@software.amazon.jsii.Jsii.Proxy(AfterwardsOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AfterwardsOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether to include error handling states.
     * <p>
     * If this is true, all states which are error handlers (added through 'onError')
     * and states reachable via error handlers will be included as well.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getIncludeErrorHandlers() {
        return null;
    }

    /**
     * Whether to include the default/otherwise transition for the current Choice state.
     * <p>
     * If this is true and the current Choice does not have a default outgoing
     * transition, one will be added included when .next() is called on the chain.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getIncludeOtherwise() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AfterwardsOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AfterwardsOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AfterwardsOptions> {
        private java.lang.Boolean includeErrorHandlers;
        private java.lang.Boolean includeOtherwise;

        /**
         * Sets the value of {@link AfterwardsOptions#getIncludeErrorHandlers}
         * @param includeErrorHandlers Whether to include error handling states.
         *                             If this is true, all states which are error handlers (added through 'onError')
         *                             and states reachable via error handlers will be included as well.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder includeErrorHandlers(java.lang.Boolean includeErrorHandlers) {
            this.includeErrorHandlers = includeErrorHandlers;
            return this;
        }

        /**
         * Sets the value of {@link AfterwardsOptions#getIncludeOtherwise}
         * @param includeOtherwise Whether to include the default/otherwise transition for the current Choice state.
         *                         If this is true and the current Choice does not have a default outgoing
         *                         transition, one will be added included when .next() is called on the chain.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder includeOtherwise(java.lang.Boolean includeOtherwise) {
            this.includeOtherwise = includeOtherwise;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AfterwardsOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AfterwardsOptions build() {
            return new Jsii$Proxy(includeErrorHandlers, includeOtherwise);
        }
    }

    /**
     * An implementation for {@link AfterwardsOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AfterwardsOptions {
        private final java.lang.Boolean includeErrorHandlers;
        private final java.lang.Boolean includeOtherwise;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.includeErrorHandlers = software.amazon.jsii.Kernel.get(this, "includeErrorHandlers", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.includeOtherwise = software.amazon.jsii.Kernel.get(this, "includeOtherwise", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.Boolean includeErrorHandlers, final java.lang.Boolean includeOtherwise) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.includeErrorHandlers = includeErrorHandlers;
            this.includeOtherwise = includeOtherwise;
        }

        @Override
        public final java.lang.Boolean getIncludeErrorHandlers() {
            return this.includeErrorHandlers;
        }

        @Override
        public final java.lang.Boolean getIncludeOtherwise() {
            return this.includeOtherwise;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIncludeErrorHandlers() != null) {
                data.set("includeErrorHandlers", om.valueToTree(this.getIncludeErrorHandlers()));
            }
            if (this.getIncludeOtherwise() != null) {
                data.set("includeOtherwise", om.valueToTree(this.getIncludeOtherwise()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-stepfunctions.AfterwardsOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AfterwardsOptions.Jsii$Proxy that = (AfterwardsOptions.Jsii$Proxy) o;

            if (this.includeErrorHandlers != null ? !this.includeErrorHandlers.equals(that.includeErrorHandlers) : that.includeErrorHandlers != null) return false;
            return this.includeOtherwise != null ? this.includeOtherwise.equals(that.includeOtherwise) : that.includeOtherwise == null;
        }

        @Override
        public final int hashCode() {
            int result = this.includeErrorHandlers != null ? this.includeErrorHandlers.hashCode() : 0;
            result = 31 * result + (this.includeOtherwise != null ? this.includeOtherwise.hashCode() : 0);
            return result;
        }
    }
}
